<?php

namespace Drupal\Tests\lb_default_blocks\Kernel;

use Drupal\lb_default_blocks\Hooks\BlockContentTypeIntegration;

/**
 * Defines a class for testing theme suggestions for block content.
 *
 * @group lb_default_blocks
 */
class ThemeSuggestionsTest extends LbDefaultBlocksKernelTestBase {

  /**
   * {@inheritdoc}
   */
  public function setUp() : void {
    parent::setUp();
    $this->enableDefaultBlockSupportForBlockType($this->createBlockContentType('text', 'Text'));
    \Drupal::service('theme_installer')->install(['lb_default_blocks_test_theme']);
    \Drupal::configFactory()->getEditable('system.theme')->set('default', 'lb_default_blocks_test_theme')->save();
  }

  /**
   * Tests per position theme suggestions.
   */
  public function testThemeSuggestions() {
    $theme = \Drupal::service('theme.initialization')->getActiveThemeByName('lb_default_blocks_test_theme');
    \Drupal::service('theme.manager')->setActiveTheme($theme);
    $this->createLayoutPosition(['id' => 'mystic_goanna']);
    $content = $this->createBlockContent([
      'type' => 'text',
      'label' => $this->randomMachineName(),
      BlockContentTypeIntegration::FIELD_NAME => 'mystic_goanna',
    ]);
    $build = \Drupal::entityTypeManager()->getViewBuilder('block_content')->view($content);
    $out = (string) \Drupal::service('renderer')->renderPlain($build);
    $this->assertStringNotContainsString($content->label(), $out);
    $this->assertStringContainsString('this template suggestion outputs stuff', $out, $out);
  }

}
